Episcanpy – Epigenomics single cell analysis in python — episcanpy 0.0.1 documentation

# Episcanpy – Epigenomics single cell analysis in python

Episcanpy is a toolkit to analyse single cell chromatin (ATACseq) and methylation (BSseq) data.

It is compatible with scanpy_ (Wolf et al., 2018). Making use of sparse implementation, iterative neighbors search and other techniques (these 2 sentences come from the rna velocity readme)

The documentation of Episcanpy is available at <https://episcanpy.readthedocs.io/en/latest/>

We are still working on pip install procedure, it should be available soon

Report issues and see the code on GitHub.

If Scanpy is useful for your research, consider citing Genome Biology (2018). When Episcanpy is released… Well cite Episcanpy too.

Note

> Also see the release notes of `scanpy`.

Also see the release notes of `anndata`.

## Version 0.0.1 January 17, 2019

blablabla